summaryrefslogtreecommitdiff
path: root/Modules/FindMatlab.cmake
diff options
context:
space:
mode:
authorJosef Angstenberger <code@jtxa.de>2021-05-07 00:16:22 +0200
committerJosef Angstenberger <code@jtxa.de>2021-05-07 17:00:16 +0200
commit87f8843d8b97cf174302858ee5344a737a520c9b (patch)
treee0d4e047d7229a9c454a455510c2a739479cccb3 /Modules/FindMatlab.cmake
parent15cc39ed7f90331401f53530e4b2d03f8573f0d1 (diff)
downloadcmake-87f8843d8b97cf174302858ee5344a737a520c9b.tar.gz
FindMatlab: Fix spelling in warning and documentation
Diffstat (limited to 'Modules/FindMatlab.cmake')
-rw-r--r--Modules/FindMatlab.cmake16
1 files changed, 8 insertions, 8 deletions
diff --git a/Modules/FindMatlab.cmake b/Modules/FindMatlab.cmake
index 502eee005c..c8df670b1b 100644
--- a/Modules/FindMatlab.cmake
+++ b/Modules/FindMatlab.cmake
@@ -52,7 +52,7 @@ The module supports the following components:
between the release name and the version.
The variable :variable:`Matlab_ROOT_DIR` may be specified in order to give
-the path of the desired Matlab version. Otherwise, the behaviour is platform
+the path of the desired Matlab version. Otherwise, the behavior is platform
specific:
* Windows: The installed versions of Matlab/MCR are retrieved from the
@@ -83,7 +83,7 @@ Module Input Variables
^^^^^^^^^^^^^^^^^^^^^^
Users or projects may set the following variables to configure the module
-behaviour:
+behavior:
:variable:`Matlab_ROOT_DIR`
the root of the Matlab installation.
@@ -184,7 +184,7 @@ Known issues
**Symbol clash in a MEX target**
By default, every symbols inside a MEX
file defined with the command :command:`matlab_add_mex` have hidden
- visibility, except for the entry point. This is the default behaviour of
+ visibility, except for the entry point. This is the default behavior of
the MEX compiler, which lowers the risk of symbol collision between the
libraries shipped with Matlab, and the libraries to which the MEX file is
linking to. This is also the default on Windows platforms.
@@ -223,7 +223,7 @@ Reference
.. variable:: MATLAB_ADDITIONAL_VERSIONS
If set, specifies additional versions of Matlab that may be looked for.
- The variable should be a list of strings, organised by pairs of release
+ The variable should be a list of strings, organized by pairs of release
name and versions, such as follows::
set(MATLAB_ADDITIONAL_VERSIONS
@@ -856,7 +856,7 @@ endfunction()
where ``matlab_file_name`` is the ``UNITTEST_FILE`` without the extension.
``UNITTEST_PRECOMMAND``
Matlab script command to be ran before the file
- containing the test (eg. GPU device initialisation based on CMake
+ containing the test (eg. GPU device initialization based on CMake
variables).
``TIMEOUT``
the test timeout in seconds. Defaults to 180 seconds as the
@@ -1240,7 +1240,7 @@ function(_Matlab_get_version_from_root matlab_root matlab_or_mcr matlab_known_ve
endif()
endif()
# UNKNOWN is the default behaviour in case we
# - have an erroneous matlab_root
# - have an initial 'UNKNOWN'
if(matlab_or_mcr STREQUAL "MATLAB" OR matlab_or_mcr STREQUAL "UNKNOWN")
@@ -1375,7 +1375,7 @@ function(_Matlab_find_instances_osx matlab_roots)
set(_matlab_possible_roots)
# on mac, we look for the /Application paths
# this corresponds to the behaviour on Windows. On Linux, we do not have
# any other guess.
matlab_get_supported_releases(_matlab_releases)
if(MATLAB_FIND_DEBUG)
@@ -1552,7 +1552,7 @@ if(_numbers_of_matlab_roots GREATER 0)
# adding a warning in case of ambiguity
if(_numbers_of_matlab_roots GREATER 3 AND MATLAB_FIND_DEBUG)
message(WARNING "[MATLAB] Found several distributions of Matlab. Setting the current version to ${Matlab_VERSION_STRING} (located ${Matlab_ROOT_DIR})."
- " If this is not the desired behaviour, use the EXACT keyword or provide the -DMatlab_ROOT_DIR=... on the command line")
+ " If this is not the desired behavior, use the EXACT keyword or provide the -DMatlab_ROOT_DIR=... on the command line")
endif()
endif()
endif()
@@ -1240,7 +1240,7 @@ function(_Matlab_get_version_from_root matlab_root matlab_or_mcr matlab_known_ve
endif()
endif()
- # UNKNOWN is the default behaviour in case we
+ # UNKNOWN is the default behavior in case we
# - have an erroneous matlab_root
# - have an initial 'UNKNOWN'
@@ -1375,7 +1375,7 @@ function(_Matlab_find_instances_osx matlab_roots)
set(_matlab_possible_roots)
# on mac, we look for the /Application paths
- # this corresponds to the behaviour on Windows. On Linux, we do not have
+ # this corresponds to the behavior on Windows. On Linux, we do not have
# any other guess.
matlab_get_supported_releases(_matlab_releases)